 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 Some core elements of Reahl can be implemented for use with
 different persistence technologies. This is such an implementation
 based on SqlAlchemy.
